%global gettext_package FontForge

Summary:        Outline and bitmap font editor
Name:           fontforge
Version:        20230101
Release:        5%{?dist}
License:        GPLv3+
URL:            http://fontforge.github.io/
Source0:        https://github.com/fontforge/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

Patch3000:      0001-Fix-errors-in-French-and-Italian-translations.patch

BuildRequires:  gcc-c++ cmake libjpeg-devel libtiff-devel libpng-devel giflib-devel
BuildRequires:  libxml2-devel freetype-devel desktop-file-utils libuninameslist-devel
BuildRequires:  xorg-x11-proto-devel libXt-devel gettext pango-devel cairo-devel
BuildRequires:  python3-devel libspiro-devel readline-devel libappstream-glib
BuildRequires:  shared-mime-info woff2-devel gtk3-devel make

Requires:       xdg-utils autotrace hicolor-icon-theme

Provides:       python-fontforge = %{version}-%{release}
Provides:       python%{python3_version}-fontforge = %{version}-%{release}
Provides:       python-psMat = %{version}-%{release}
Provides:       python%{python3_version}-psMat = %{version}-%{release}

%description
FontForge (former PfaEdit) is a font editor for outline and bitmap fonts.
It supports a range of font formats, including PostScript (ASCII and binary
Type 1, some Type 3 and Type 0), TrueType, OpenType (Type2) and CID-keyed fonts.

%package devel
Summary: Development files for fontforge
Requires: %{name} = %{version}-%{release}
Provides: %{name}-doc = %{version}-%{release}

%description devel
This package includes the library files you will need to compile applications
against fontforge and documentation files.

%prep
%autosetup -n %{name}-%{version} -p1

# Remove tests which will require Internet access
sed -i '45d;82d;101d;102d;114d;115d;127d' tests/CMakeLists.txt
rm tests/test003.pe tests/test130.pe tests/test0101.py tests/test929.py

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%cmake -DCMAKE_BUILD_TYPE=Release \
          -DENABLE_WOFF2=ON
%cmake_build

%install
%cmake_install
desktop-file-install \
  --dir %{buildroot}%{_datadir}/applications            \
  desktop/org.fontforge.FontForge.desktop

find %{buildroot} -name '*.la' -exec rm -f {} ';'
find %{buildroot} -name '*.a' -exec rm -f {} ';'

rm -f %{buildroot}%{_datadir}/doc/fontforge/{.buildinfo,.nojekyll}
appstream-util validate-relax --nonet %{buildroot}%{_metainfodir}/*.appdata.xml

%find_lang FontForge

%check
pushd %{__cmake_builddir}
%make_build check
popd

%files -f FontForge.lang
%license LICENSE COPYING.gplv3
%doc AUTHORS
%{_bindir}/*
%{_libdir}/lib*.so.*
%{_datadir}/applications/*FontForge.desktop
%{_datadir}/fontforge
%{_datadir}/icons/hicolor/*/apps/org.fontforge.FontForge*
%{_datadir}/mime/packages/fontforge.xml
%{_metainfodir}/org.fontforge.FontForge.appdata.xml
%{python3_sitearch}/fontforge.so
%{python3_sitearch}/psMat.so
%{_mandir}/man1/*.1*

%files devel
%doc %{_pkgdocdir}
%{_libdir}/lib*.so

%changelog
* Thu Oct 19 2023 kianli <kianli@tencent.com> - 20230101-5
- Rebuilt for autotrace 0.31.9

* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20230101-4
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20230101-3
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 29 2023 jackeyji <jackeyji@tencent.com> - 20230101-2
- rebuild for libspiro 20221101

* Wed Aug 02 2023 kianli <kianli@tencent.com> - 20230101-1
- Upgrade to 20230101 and rebuilt for libtiff 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20201107-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 20201107-2
- Rebuilt for OpenCloudOS Stream 23

* Wed Nov 23 2022 Shuo Wang <abushwang@tencent.com> - 20201107-1
- initial build
